"use client";

import {
	useToaster,
	Text,
	Divider,
	Code,
	Surface,
	Flex,
	LinkAction,
	LinkBox,
} from "@itwin/itwinui-react";
import { setGlobalToaster } from "modules/globals/toaster";

import styles from "./page.module.scss";

import Link from "next/link";

export default function App() {
	// Initialize toaster
	setGlobalToaster(useToaster());

	return <Content />;
}

const Content = () => {
	return (
		<div className={styles["inner-content"]}>
			<div className={styles["title-bar"]}>
				<Text as="h1" variant="headline" className="headline">
					iTwinUI Migration Tool
				</Text>
				<Text as="p" variant="body" className={styles["paragraphs"]}>
					This tool helps to perform semi-automated migrations for the below iTwinUI versions.
					Choose your target version to get started:
				</Text>
			</div>
			<Flex justifyContent="center" alignItems="stretch">
				<ToolSelectorCard
					label="iTwinUI v2"
					subLabel={`Rudimentary find-and-replace`}
					href="/v2"
					description={
						<>
							<Text as={Flex.Item} flex={999}>
								For upgrading from <Code>@itwin/itwinui-css@0</Code> to{" "}
								<Code>@itwin/itwinui-css@1</Code> and <Code>@itwin/itwinui-variables@2</Code>
							</Text>
						</>
					}
				/>
				<ToolSelectorCard
					label="iTwinUI v3"
					subLabel={`Improved codemods`}
					href="/v3"
					description={
						<>
							<Text as={Flex.Item} flex={999}>
								For upgrading from <Code>@itwin/itwinui-react@2</Code> to{" "}
								<Code>@itwin/itwinui-react@3</Code>
							</Text>
						</>
					}
				/>
			</Flex>
		</div>
	);
};

const ToolSelectorCard = (props: {
	label: string;
	subLabel: string;
	description?: string | JSX.Element;
	href: string;
}) => {
	const { label, subLabel, description, href } = props;

	return (
		<Surface as={LinkBox} className={styles["tile-wrapper"]}>
			<Surface.Header
				as={Flex}
				gap={"2xs"}
				flexDirection="column"
				alignItems={"flex-start"}
				className={styles["tile-header"]}
			>
				<LinkAction as={Link} href={href}>
					<Text as="h2" variant="subheading" className={styles["tile-heading"]}>
						{label}
					</Text>
				</LinkAction>
				<Text variant="small" isMuted>
					{subLabel}
				</Text>
			</Surface.Header>
			<Divider />
			<Surface.Body
				as={Flex}
				alignItems="flex-start"
				flexDirection="column"
				className={styles["tile-body"]}
			>
				{description}
			</Surface.Body>
		</Surface>
	);
};
