import { Flex, Text } from "@itwin/itwinui-react";
import { CustomBreadcrumbs } from "./CustomBreadcrumbs";
import { CustomReactMarkdown } from "app/_ui/CustomReactMarkdown";
import styles from "./PageHeader.module.scss";
import { Divider } from "@itwin/itwinui-react";

export const PageHeader = ({
	customBreadcrumbsProps,
	instructionsProps,
	applyDefaultStyles = true,
}: {
	customBreadcrumbsProps: React.ComponentPropsWithoutRef<typeof CustomBreadcrumbs>;
	instructionsProps: React.ComponentPropsWithoutRef<typeof Instructions>;
	/**
	 * Whether to apply default styles to the breadcrumbs (e.g. margin-bottom).
	 */
	applyDefaultStyles?: boolean;
}) => {
	return (
		<Flex
			flexDirection="column"
			alignItems="flex-start"
			data-apply-default-styles={applyDefaultStyles}
			className={styles.root}
		>
			<CustomBreadcrumbs {...customBreadcrumbsProps} />
			<Instructions {...instructionsProps} />
			<Divider />
		</Flex>
	);
};

const Instructions = ({
	title,
	description,
}: {
	title: string;
	description: string;
}) => {
	return (
		<Flex flexDirection="column" alignItems="flex-start" gap="3xs" className={styles.instructions}>
			<Text as="h1" variant="title">
				{title}
			</Text>
			<CustomReactMarkdown>{description}</CustomReactMarkdown>
		</Flex>
	);
};
