"use client";

import { Button, Dialog, Divider, Flex, Surface, Text } from "@itwin/itwinui-react";
import type { LatestRunFile } from "utils/latestFileRun";
import Link from "next/link";
import React from "react";
import styles from "./PreviousRunCard.module.scss";

export const PreviousRunCard = ({
	latestRunFile,
	deleteButton,
}: {
	latestRunFile: LatestRunFile | null;
	deleteButton: React.ReactNode;
}) => {
	const [isDialogOpen, setIsDialogOpen] = React.useState(false);

	if (latestRunFile == null) {
		return undefined;
	}

	const lastModified = new Date(latestRunFile.lastModified);
	const lastModifiedDisplayString = `${lastModified.toLocaleDateString()} ${lastModified.toLocaleTimeString()}`;

	return (
		<>
			<Flex flexDirection="column" alignItems="flex-start">
				<Text as="h2" variant="title">
					Continue previous run?
				</Text>
				<Text>
					You already have a started a run. Either continue that run or start a new one (previous
					run info would be deleted).
				</Text>
				<Surface>
					<Surface.Header>
						<Text variant="subheading">Previous run</Text>
					</Surface.Header>

					<Divider />

					<Surface.Body className={styles.surfaceBody}>
						<Flex flexDirection="column" alignItems="flex-start">
							<Text isMuted>Repo path:</Text>
							<Text>{latestRunFile.repoFolder}</Text>
							<Text isMuted>Latest run:</Text>
							<Text>{lastModifiedDisplayString}</Text>
							<Flex>
								<Button as={Link} href={"/v3/preview"} styleType="high-visibility">
									Continue
								</Button>
								<Button onClick={() => setIsDialogOpen(true)}>Start new run</Button>
							</Flex>
						</Flex>
					</Surface.Body>
				</Surface>
			</Flex>
			<DeletePreviousRunDialog
				isDialogOpen={isDialogOpen}
				setIsDialogOpen={setIsDialogOpen}
				deleteButton={deleteButton}
			/>
		</>
	);
};

// ------------------------------------------------------------------------------------------------

const DeletePreviousRunDialog = ({
	isDialogOpen,
	setIsDialogOpen,
	deleteButton,
}: {
	isDialogOpen: boolean;
	setIsDialogOpen: (value: boolean) => void;
	deleteButton: React.ReactNode;
}) => {
	return (
		<Dialog
			isOpen={isDialogOpen}
			onClose={() => setIsDialogOpen(false)}
			closeOnEsc
			isDismissible
			closeOnExternalClick
		>
			<Dialog.Backdrop />
			<Dialog.Main>
				<Dialog.TitleBar>Start new run?</Dialog.TitleBar>
				<Dialog.Content>
					<Text>
						This will delete all the information about the previous run. Are you sure you want to
						start a new run?
					</Text>
				</Dialog.Content>
				<Dialog.ButtonBar>
					{deleteButton}
					<Button onClick={() => setIsDialogOpen(false)}>Cancel</Button>
				</Dialog.ButtonBar>
			</Dialog.Main>
		</Dialog>
	);
};
