"use client";

import * as React from "react";
import styles from "./CustomDiffEditor.module.scss";
import { AppThemeContext } from "modules/contexts/contexts";
import { DiffEditor } from "@monaco-editor/react";
import cx from "classnames";

export const CustomDiffEditor = ({
	className,
	originalCode,
	modifiedCode,
}: {
	className?: string;
	originalCode: string;
	modifiedCode: string;
}) => {
	const appThemeProvider = React.useContext(AppThemeContext);
	const prefersDark = useMediaQuery("(prefers-color-scheme: dark)");
	const shouldApplyDark =
		appThemeProvider.theme === "dark" || (appThemeProvider.theme === "os" && prefersDark);

	return (
		<DiffEditor
			className={cx(className, styles.diff)}
			language="javascript"
			options={{
				readOnly: true,
			}}
			original={originalCode}
			modified={modifiedCode}
			theme={shouldApplyDark ? "vs-dark" : "vs-light"}
		/>
	);
};

// ------------------------------------------------------------------------------------------------

const useMediaQuery = (queryString: string) => {
	const mediaQuery = () => matchMedia?.(queryString);

	return React.useSyncExternalStore(
		(handleChange) => {
			mediaQuery().addEventListener("change", handleChange);
			return () => {
				mediaQuery().removeEventListener("change", handleChange);
			};
		},
		() => mediaQuery().matches,
	);
};
