import * as React from "react";
import { PreviewPageContent } from "./PreviewPageContent";
import { PageHeader } from "../PageHeader";
import { readOutputFile } from "app/_actions/readOutputFile";
import { ProgressRadial } from "@itwin/itwinui-react";

const description = `View all the dry run outputs of your codemods. Expand each table row to see what codemods are applicable to that file and the code diff.
          
Inside each file:
* Toggle the codemod checkboxes to see the code diff change.
* Once you are happy with the codemod selection for a file, you can click the \`Run x codemods\` button to run the selected codemods in that file.

Bulk run codemods:
* A quicker approach is to select multiple rows and then click the top-right \`Run codemods in x files\` button to bulk run codemods in all the selected files.

Make sure you go to the \`Results/Suggestions\` page to view suggestions and manual required/optional changes.
`.trim();

export default async function App() {
	return (
		<>
			<PageHeader
				customBreadcrumbsProps={{
					route: "/v3/preview",
				}}
				instructionsProps={{
					title: "Preview",
					description: description,
				}}
			/>
			<React.Suspense fallback={<ProgressRadial />}>
				<PageContent />
			</React.Suspense>
		</>
	);
}

const PageContent = async () => {
	const latestRunFile = await readOutputFile();

	return <>{latestRunFile != null && <PreviewPageContent latestRunFile={latestRunFile} />}</>;
};

export const dynamic = "force-dynamic";
