import { Divider, ExpandableBlock, IconButton, Surface, Text } from "@itwin/itwinui-react";
import styles from "./ManualSuggestionCard.module.scss";
import { Suggestion } from "data/codemod_types";
import { SvgClose, SvgUndo } from "@itwin/itwinui-icons-react";
import { CustomReactMarkdown } from "app/_ui/CustomReactMarkdown";
import { getFileNameAndPath } from "utils/utils";
import { toggleDismissedSuggestion } from "app/_actions/toggleDismissedSuggestion";
import React from "react";
import { OpenFileInIDELink } from "app/_ui/OpenFileInIDELink";

export const ManualSuggestionCard = ({
	suggestion,
}: {
	suggestion: Suggestion;
}) => {
	const fileNameAndPath = getFileNameAndPath(suggestion.file, "");

	const fileName = fileNameAndPath.fileName;
	const lineNumber = suggestion.message.start.line;
	const columnNumber = suggestion.message.start.column;
	const fileNameWithLineAndColumn = `${fileName}:${lineNumber}:${columnNumber}`;

	async function toggleDismissedFormAction(formData: FormData) {
		try {
			const result = await toggleDismissedSuggestion(formData);
			if (result == null || result.success === false) {
				throw new Error("result == null || success != true");
			}
		} catch (error) {
			console.error("form action error", error);
		}
	}

	const codeContent = React.useMemo(() => {
		const linesBefore = suggestion.message.linesBefore?.join("\n") ?? "";
		const lineContent = "- " + suggestion.message.lineContent ?? "";
		const linesAfter = suggestion.message.linesAfter?.join("\n") ?? "";

		return `\`\`\`diff\n${linesBefore}\n${lineContent}\n${linesAfter}\n\`\`\``;
	}, [suggestion.message]);

	return (
		<Surface className={styles["root"]} data-dismissed={suggestion.dismissed}>
			<div className={styles["content"]}>
				<div className={styles["title-div"]}>
					<OpenFileInIDELink filePath={`${suggestion.file}:${lineNumber}:${columnNumber}`}>
						<Text variant="subheading">{fileNameWithLineAndColumn}</Text>
					</OpenFileInIDELink>
					<Text className={styles["filepath"]} variant="small">
						{fileNameAndPath.path}
					</Text>
				</div>
				<CustomReactMarkdown className={styles["message-content"]}>
					{suggestion.message.content}
				</CustomReactMarkdown>
				<Divider />
				<ExpandableBlock.Wrapper styleType="borderless">
					<ExpandableBlock.Trigger label="Code" />
					<ExpandableBlock.Content>
						<CustomReactMarkdown>{codeContent}</CustomReactMarkdown>
					</ExpandableBlock.Content>
				</ExpandableBlock.Wrapper>
			</div>
			<form action={toggleDismissedFormAction}>
				<IconButton
					styleType="borderless"
					type="submit"
					name="suggestion-id"
					value={suggestion.id}
					label={suggestion.dismissed ? "Un-dismiss" : "Dismiss"}
				>
					{suggestion.dismissed ? <SvgUndo /> : <SvgClose />}
				</IconButton>
			</form>
		</Surface>
	);
};
