"use client";

import { Flex, Text, Tabs, Tab } from "@itwin/itwinui-react";
import React from "react";
import { ManualSuggestionCard } from "./ManualSuggestionCard";
import styles from "./ManualSuggestions.module.scss";
import { Suggestion } from "data/codemod_types";
import type { LatestRunFile } from "utils/latestFileRun";

const tabs = ["Active", "Dismissed"] as const;

export const ManualSuggestions: React.FC<{
	suggestions: Suggestion[];
	latestRunFile: LatestRunFile;
}> = ({ suggestions, latestRunFile }) => {
	const [activeTab, setActiveTab] = React.useState<typeof tabs[number]>("Active");

	const filteredSuggestions = suggestions.filter((s) => {
		const foundFile = latestRunFile.files.find((file) => file.filePath === s.file);

		// File is found (file has at least one applicable codemod)
		if (foundFile != null) {
			const isFoundFileFinishedRunning = foundFile?.state === "finished-running";
			const isSuggestionCodemodRunOnFile = foundFile?.stages
				.map((stage) => stage.codemod)
				.includes(s.codemod);

			return isFoundFileFinishedRunning && isSuggestionCodemodRunOnFile;
		}

		// File is NOT found (file has no applicable codemods)
		// But we still want to show the suggestion
		return true;
	});
	const activeSuggestions = filteredSuggestions.filter((s) => !s.dismissed);
	const dismissedSuggestions = filteredSuggestions.filter((s) => s.dismissed);

	return (
		<Tabs
			labels={[
				<Tab key="Active" label={`Active (${activeSuggestions.length})`} />,
				<Tab key="Dismissed" label={`Dismissed (${dismissedSuggestions.length})`} />,
			]}
			onTabSelected={(index) => setActiveTab(tabs[index])}
			type="borderless"
		>
			<SuggestionsList
				suggestions={activeTab === "Active" ? activeSuggestions : dismissedSuggestions}
			/>
		</Tabs>
	);
};

const SuggestionsList = ({ suggestions }: { suggestions: Suggestion[] }) => {
	return (
		<div className={styles["suggestions"]}>
			{suggestions.length > 0 ? (
				suggestions.map((suggestion) => {
					return <ManualSuggestionCard key={suggestion.id} suggestion={suggestion} />;
				})
			) : (
				<Text>
					You have no suggestions. If you haven&apos;t already, make sure you have run the codemods
					from the home page.
				</Text>
			)}
		</div>
	);
};
