import * as React from "react";

import fs from "fs";
import { suggestionsFilePath } from "utils/codemods";
import { Flex, ProgressRadial, Text } from "@itwin/itwinui-react";
import { ManualSuggestions } from "./ManualSuggestions";
import { ResultStats } from "./ResultStats";
import { readOutputFile } from "app/_actions/readOutputFile";
import { CustomReactMarkdown } from "app/_ui/CustomReactMarkdown";

export default async function Page() {
	return (
		<>
			<Flex flexDirection="column" gap="m" alignItems="flex-start">
				<ResultStats />
				<Flex flexDirection="column" gap="l" alignItems="stretch">
					<TitleAndDescription />
					<React.Suspense fallback={<ProgressRadial indeterminate />}>
						<Suggestions />
					</React.Suspense>
				</Flex>
			</Flex>
		</>
	);
}

async function Suggestions() {
	const suggestions = await getSuggestions();
	const latestRunFile = await readOutputFile();

	return (
		latestRunFile != null && (
			<ManualSuggestions suggestions={suggestions} latestRunFile={latestRunFile} />
		)
	);
}

const TitleAndDescription = () => {
	return (
		<Flex flexDirection="column" alignItems="flex-start">
			<Text variant="title" as="h1">
				Suggestions
			</Text>
			<CustomReactMarkdown>
				{`These are required (or sometimes optional) suggestions that you need to
        act upon manually or tidbits of information to help you make an informed
        decision. If you haven't already, make sure you have run the
        codemods from the v3 home page (\`/v3\`).`}
			</CustomReactMarkdown>
		</Flex>
	);
};

async function getSuggestions() {
	const suggestions = fs.readFileSync(suggestionsFilePath, "utf-8");
	return JSON.parse(suggestions);
}

export const dynamic = "force-dynamic";
