"use server";

import { setFileStateToFinishedRunningCodemods, toggleIgnoreFile } from "modules/v3/logic/codemods";

import type { LatestRunFile } from "utils/latestFileRun";
import { writeLatestRunFile } from "utils/latestFileRun";
import { revalidatePath } from "next/cache";
import { readOutputFile } from "./readOutputFile";
import { redirect } from "next/navigation";

export const bulkUpdateAllCodemoddedFiles = async (formData: FormData) => {
	const result = await runBulkUpdates(formData);

	revalidatePath("/v3/preview");

	const shouldShowResults = (formData.get("should-show-results") ?? "false") === "true";

	if (shouldShowResults) {
		redirect("/v3/results");
	}

	if (!result) return "oops";
};

export const bulkUpdateCodemoddedFiles = async (formData: FormData) => {
	const result = await runBulkUpdates(formData);
	revalidatePath("/v3/preview");
	revalidatePath("/v3/results"); // Since suggestion page also reads latestRunFile
	return result;
};

async function runBulkUpdates(formData: FormData) {
	try {
		const filePaths = formData.getAll("file-path");
		const newState = formData.get("new-state");

		if (typeof newState !== "string") throw "oops";

		let newLatestRunFile = await readOutputFile();
		if (newLatestRunFile == null) {
			throw "oops";
		}

		for (const filePath of filePaths) {
			if (typeof filePath !== "string") throw "oops";

			const result = await runUpdateCodemoddedFileState({
				filePath,
				newState,
				preExistingLatestRunFile: newLatestRunFile,
			});
			if (result == null) {
				throw "oops";
			}

			newLatestRunFile = result;
		}

		// Update latestRunFile
		writeLatestRunFile(newLatestRunFile);

		return newLatestRunFile;
	} catch (error) {
		console.error("ERROR:", error);
		return null;
	}
}

async function runUpdateCodemoddedFileState({
	filePath,
	newState,
	preExistingLatestRunFile,
}: {
	filePath: string;
	newState: string; // LatestRunFile["files"][number]["state"];
	preExistingLatestRunFile: LatestRunFile;
}) {
	let newCodemoddedFile: LatestRunFile["files"][number] | undefined = undefined;

	try {
		const latestRunFile = preExistingLatestRunFile;
		if (latestRunFile == null) {
			throw "oops";
		}

		const oldCodemoddedFile = latestRunFile.files.find((file) => file.filePath === filePath);
		if (oldCodemoddedFile == null) {
			throw "oops";
		}

		if (newState === "finished-running") {
			newCodemoddedFile = setFileStateToFinishedRunningCodemods(oldCodemoddedFile);
		} else if (newState === "ignored") {
			newCodemoddedFile = toggleIgnoreFile(oldCodemoddedFile, true);
		} else if (newState === "active") {
			newCodemoddedFile = toggleIgnoreFile(oldCodemoddedFile, false);
		}

		if (newCodemoddedFile == null) {
			throw "oops";
		}

		const latestRunFileIndex = latestRunFile.files.findIndex((file) => file.filePath === filePath);

		latestRunFile.files[latestRunFileIndex] = newCodemoddedFile;

		return latestRunFile;
	} catch (error) {
		console.error("ERROR:", error);
		return null;
	}
}
