"use server";

import { Suggestion } from "data/codemod_types";
import fs from "fs";
import { revalidatePath } from "next/cache";
import { suggestionsFilePath } from "utils/codemods";

/**
 * Toggle the dismissed state of a suggestion
 * @param formData { "suggestion-id": "..." }
 */
export async function toggleDismissedSuggestion(formData: FormData) {
	try {
		const suggestionId = formData.get("suggestion-id");

		if (typeof suggestionId !== "string") throw "oops";

		const suggestions: Suggestion[] = JSON.parse(fs.readFileSync(suggestionsFilePath, "utf-8"));
		const suggestion = suggestions.find((suggestion) => suggestion.id === suggestionId);

		if (suggestion) {
			suggestion.dismissed = !suggestion.dismissed;
		}

		// Write the new suggestions to the file
		fs.writeFileSync("logs/v3/suggestions.json", JSON.stringify(suggestions, null, 2));

		revalidatePath("/v3/suggestions");
		return {
			success: true,
			newDismissedValue: suggestion?.dismissed,
		};
	} catch (error) {
		console.error(error);
	}
}
