"use server";

import { reRunCodemod } from "modules/v3/logic/codemods";
import { SupportedCodemods } from "codemods/codemods";

import type { LatestRunFile } from "utils/latestFileRun";
import { writeLatestRunFile } from "utils/latestFileRun";
import { readOutputFile } from "./readOutputFile";
import { revalidatePath } from "next/cache";

export default async function updateCodemoddedFile(formData: FormData) {
	let newCodemoddedFile: LatestRunFile["files"][number] | null = null;

	try {
		const filePath = formData.get("file-path");
		const codemodsToRun = formData.getAll("codemods-to-run");

		if (typeof filePath !== "string") throw "oops";
		codemodsToRun.forEach((codemod) => {
			if (typeof codemod !== "string") throw "oops";
		});

		const preExistingLatestRunFile = await readOutputFile();
		if (preExistingLatestRunFile == null) {
			throw "oops";
		}

		newCodemoddedFile = await reRunCodemod({
			filePath: filePath as string,
			codemodsToRun: codemodsToRun as SupportedCodemods[],
			preExistingLatestRunFile,
		});
		if (newCodemoddedFile == null) {
			throw "oops";
		}

		const preExistingLatestRunFileIndex = preExistingLatestRunFile.files.findIndex(
			(file) => file.filePath === filePath,
		);

		preExistingLatestRunFile.files[preExistingLatestRunFileIndex] = newCodemoddedFile;

		// Update latestRunFile
		writeLatestRunFile(preExistingLatestRunFile);

		revalidatePath("/v3/preview");

		return preExistingLatestRunFile;
	} catch (error) {
		console.error("ERROR:", error);
		return null;
	}
}
