import { Anchor } from "@itwin/itwinui-react";
import ReactMarkdown from "react-markdown";
import styles from "./CustomReactMarkdown.module.scss";

export const CustomReactMarkdown = ({
	className,
	children,
}: {
	className?: string;
	children: string;
}) => {
	return (
		<ReactMarkdown
			className={className}
			components={{
				a: customMarkdownLinkRenderer,
				p: customMarkdownParagraphRenderer,
				ul: customMarkdownUnorderedListRenderer,
				pre: customPreRenderer,
				code: customCodeRenderer,
			}}
		>
			{children}
		</ReactMarkdown>
	);
};

const customMarkdownLinkRenderer = (props: any) => {
	return (
		<Anchor href={props.href} target="_blank" rel="noreferrer">
			{props.children}
		</Anchor>
	);
};

const customMarkdownParagraphRenderer = (props: any) => {
	return <p className={styles.paragraph}>{props.children}</p>;
};

const customMarkdownUnorderedListRenderer = (props: any) => {
	return <ul className={styles.unorderedList}>{props.children}</ul>;
};

const customPreRenderer = (props: any) => {
	return <pre className={styles.pre}>{props.children}</pre>;
};

const customCodeRenderer = (props: any) => {
	return <code className={styles.code}>{props.children}</code>;
};
