import chalk from "chalk";
import ora from "ora";
import { exec } from "child_process";

const checkForUpdates = async () => {
	let spinner = ora("Checking for updates").start();

	const behindCountCommand = `git rev-list --count HEAD..origin/main`;
	const aheadCountCommand = `git rev-list --count origin/main..HEAD`;

	let behindCount = null;
	let aheadCount = null;

	try {
		const gitFetchSuccess = await new Promise((resolve, reject) => {
			exec("git fetch", (error, stdout, stderr) => {
				if (error) {
					resolve(false);
				} else {
					resolve(true);
				}
			});
		});
		if (!gitFetchSuccess) {
			throw "";
		}

		behindCount = await new Promise((resolve, reject) => {
			exec(behindCountCommand, (error, stdout, stderr) => {
				if (error) {
					resolve(null);
				} else {
					resolve(Number(stdout));
				}
			});
		});
		if (behindCount == null) {
			throw "";
		}

		aheadCount = await new Promise((resolve, reject) => {
			exec(aheadCountCommand, (error, stdout, stderr) => {
				if (error) {
					resolve(null);
				} else {
					resolve(Number(stdout));
				}
			});
		});
		if (aheadCount == null) {
			throw "";
		}
	} catch (e) {
		spinner.fail(
			`Failed to check for updates:
  • If you cloned the repo, try running "git pull" manually (recommended)
  • If you downloaded the zip version, consider downloading/checking for the latest zip if it has been a long while.`,
		);
		return;
	}

	if (behindCount === 0 && aheadCount > 0) {
		spinner.warn(chalk.bgYellow("This version is ahead. Revert back to origin/main"));
	} else if (behindCount > 0 && aheadCount === 0) {
		spinner.warn(chalk.bgYellow('New version available. Run "npm run update" (recommended)'));
	} else {
		spinner.succeed("😎 You have the latest version of the tool");
	}
};

checkForUpdates();
