import { Checkbox } from "@itwin/itwinui-react";
import React from "react";

// Without label:

// In v2: When Checkbox was passed without label, className and style was being passed to the checkbox.
// This is same as in v3. So do nothing.
<Checkbox className={"my-checkbox-class"} style={{ color: "red" }} />;

// With label:

// When wrapperProps already exists, we should do nothing.
// This is because looks like the user already know about wrapperProps.
// Thus, they likely wanted the className and/or style to really be applied to the <input> and not the wrapper.
<Checkbox
  label="Checkbox label"
  className="my-checkbox-class"
  style={{ color: "red" }}
  wrapperProps={{
    onClick: () => {},
  }}
/>;

// When wrapperProps does not already exist, we should add it along with className inside it.
// Both className and style
<Checkbox
  label="Checkbox label"
  wrapperProps={{
    className: "my-checkbox-class",
    style: { color: "red" }
  }} />;

// Only className
<Checkbox label="Checkbox label" wrapperProps={{
  className: "my-checkbox-class"
}} />;

// Only style
<Checkbox label="Checkbox label" wrapperProps={{
  style: { color: "red" }
}} />;

// className="string"
<Checkbox label="Checkbox label" wrapperProps={{
  className: "my-checkbox-class"
}} />;

// className={"string in expression"}
<Checkbox label="Checkbox label" wrapperProps={{
  className: "my-checkbox-class"
}} />;

// className={variable}
const myCheckboxClass = "my-checkbox-class";
<Checkbox label="Checkbox label" wrapperProps={{
  className: myCheckboxClass
}} />;

// className={variable + "string"}
<Checkbox
  label="Checkbox label"
  wrapperProps={{
    className: myCheckboxClass + "my-checkbox-class-2"
  }}
/>;

// style=object
<Checkbox label="Checkbox label" wrapperProps={{
  style: { color: "red" }
}} />;

// style={variable}
const myCheckboxStyle = { color: "red" };
<Checkbox label="Checkbox label" wrapperProps={{
  style: myCheckboxStyle
}} />;

// style={complex expression}
const shouldApplyStyle = true;
<Checkbox
  label="Checkbox label"
  wrapperProps={{
    style: shouldApplyStyle ? { backgroundColor: "green", ...myCheckboxStyle } : {}
  }}
/>;

// className and/or style as spread attribute (no action)
const props = {
  className: "my-radio-tile",
  style: { color: "red" },
};
<Checkbox label="Checkbox label" {...props} />;