import React from "react";

// Should NOT be changed
import {
	Breadcrumbs,
	Checkbox,
	Title,
	MenuItem,
	RadioTileGroup,
	RadioTile,
	Avatar,
	type AvatarProps,
	type ButtonProps,
	SideNavigation,
	SplitButton,
	Tile,
	IconButton,
	toaster,
	UserIconGroup,
	UserIcon,
	useTheme,
} from "foobar";
// Should be changed
import {
	Button,
	Breadcrumbs as ITwinUIBreadcrumbs,
	Checkbox as ITwinUICheckbox,
	Headline,
	Subheading as ITwinUISubheading,
	MenuItem as ITwinUIMenuItem,
	RadioTileGroup as ITwinUIRadioTileGroup,
	RadioTile as ITwinUIRadioTile,
	Avatar as ITwinUIAvatar,
	Button as ITwinUIButton,
	type AvatarProps as ITwinUIPropsForAvatar,
	type ButtonProps as ITwinUIPropsForButton,
	type CarouselProps as ITwinUIPropsForCarousel,
	SideNavigation as ITwinUISideNavigation,
	SplitButton as ITwinUISplitButton,
	Tile as ITwinUITile,
	IconButton as ITwinUIIconButton,
	toaster as iTwinUIToaster,
	UserIconGroup as ITwinUIUserIconGroup,
	UserIcon as ITwinUIUserIcon,
	useTheme as iTwinUIUseTheme,
} from "@itwin/itwinui-react";

import { SvgCrop, SvgSmileyHappy } from "@itwin/itwinui-icons-react";

const menuItems = () => [
	<ITwinUIMenuItem key={1}>Item #1</ITwinUIMenuItem>,
	<ITwinUIMenuItem key={2}>Item #2</ITwinUIMenuItem>,
];

function App() {
	return (
		<>
			{/* ------------------------------------------------------------------------------------------------ */}
			{/* breadcrumbs-children */}

			{/* Should NOT be changed */}
			<Breadcrumbs>
				<a href="/">Item 1</a>
				<Button onClick={() => {}}>Item 2</Button>
				<span>Item 3</span>
			</Breadcrumbs>

			{/* Should be changed */}
			<ITwinUIBreadcrumbs>
				<a href="/">Item 1</a>
				<Button onClick={() => {}}>Item 2</Button>
				<span>Item 3</span>
			</ITwinUIBreadcrumbs>

			{/* Unrelated to the codemod */}
			<Button>foobar</Button>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* checkbox-move-style-class-inside */}

			{/* Should NOT be changed */}
			<Checkbox label="Checkbox label" className="my-checkbox-class" style={{ color: "red" }} />

			{/* Should be changed */}
			<ITwinUICheckbox
				label="Checkbox label"
				className="my-checkbox-class"
				style={{ color: "red" }}
			/>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* deprecated-typography */}

			{/* Should NOT be changed */}
			<Title>foobar</Title>

			{/* Should be changed */}
			<Headline>foobar</Headline>
			<ITwinUISubheading>foobar</ITwinUISubheading>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* menuitem-icon-badge-deprecated */}

			{/* Should NOT be changed */}
			<MenuItem key={1} onClick={() => close()} icon={<SvgCrop />} badge={<SvgCrop />}>
				Crop
			</MenuItem>

			{/* Should be changed */}
			<ITwinUIMenuItem key={1} onClick={() => close()} icon={<SvgCrop />} badge={<SvgCrop />}>
				Crop
			</ITwinUIMenuItem>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* radiotile-move-style-class-inside */}

			{/* Should NOT be changed */}
			<RadioTileGroup label="My group">
				<RadioTile
					label="My tile"
					description="Some info"
					icon={<SvgSmileyHappy />}
					className="my-radio-tile"
					style={{ color: "red" }}
				/>
			</RadioTileGroup>

			{/* Should be changed */}
			<ITwinUIRadioTileGroup label="My group">
				<ITwinUIRadioTile
					label="My tile"
					description="Some info"
					icon={<SvgSmileyHappy />}
					className="my-radio-tile"
					style={{ color: "red" }}
				/>
			</ITwinUIRadioTileGroup>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* react-table-import */}

			{/* Not applicable */}

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* remove-import-props */}

			{/* No code needed for this test. Only imports needed */}

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* setfocus-removed */}

			{/* Should NOT be changed */}
			<Checkbox label="Checkbox label" setFocus={false} />

			{/* Should be changed */}
			<ITwinUICheckbox label="Checkbox label" setFocus={false} />

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* sidenavigation-move-style-class-inside */}

			{/* Should NOT be changed */}
			<SideNavigation
				className="my-side-navigation"
				style={{ color: "red" }}
				items={[]}
				secondaryItems={[]}
			/>

			{/* Should be changed */}
			<ITwinUISideNavigation
				className="my-side-navigation"
				style={{ color: "red" }}
				items={[]}
				secondaryItems={[]}
			/>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* splitbutton-classname */}

			{/* Should NOT be changed */}
			<SplitButton className="my-button-class" aria-label={"More button"} menuItems={menuItems}>
				...
			</SplitButton>

			{/* Should be changed */}
			<ITwinUISplitButton
				className="my-button-class"
				aria-label={"More button"}
				menuItems={menuItems}
			>
				...
			</ITwinUISplitButton>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* tile-iconbutton-size */}

			{/* Should NOT be changed */}
			<Tile
				name="Tile"
				leftIcon={<IconButton styleType="borderless">...</IconButton>}
				rightIcon={<IconButton styleType="borderless">...</IconButton>}
			/>
			<ITwinUITile
				name="Tile"
				leftIcon={<IconButton styleType="borderless">...</IconButton>}
				rightIcon={<IconButton styleType="borderless">...</IconButton>}
			/>

			{/* Should be changed */}
			<ITwinUITile
				name="Tile"
				leftIcon={<ITwinUIIconButton styleType="borderless">...</ITwinUIIconButton>}
				rightIcon={<ITwinUIIconButton styleType="borderless">...</ITwinUIIconButton>}
			/>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* usericon-deprecated */}

			{/* Should NOT be changed */}
			<UserIconGroup iconSize="medium">
				<UserIcon
					size="small"
					title="Terry Rivers"
					abbreviation="TR"
					backgroundColor="green"
					image={<img src="https://cdn.example.com/user/profile/pic.png" />}
					status="online"
				/>

				<UserIcon size="medium" title="Terry Rivers" abbreviation="TR" backgroundColor="green" />
			</UserIconGroup>

			{/* Should be changed */}
			<ITwinUIUserIconGroup iconSize="medium">
				<ITwinUIUserIcon
					size="small"
					title="Terry Rivers"
					abbreviation="TR"
					backgroundColor="green"
					image={<img src="https://cdn.example.com/user/profile/pic.png" />}
					status="online"
				/>

				<ITwinUIUserIcon
					size="medium"
					title="Terry Rivers"
					abbreviation="TR"
					backgroundColor="green"
				/>
			</ITwinUIUserIconGroup>

			{/* ------------------------------------------------------------------------------------------------ */}
			{/* usericon-deprecated */}
		</>
	);
}

// ------------------------------------------------------------------------------------------------
// toaster-to-usetoaster

// Should NOT be changed
const Component1 = () => {
	return (
		<div>
			<button onClick={() => toaster.positive("hello")}>show</button>;
		</div>
	);
};

// Should be changed
const Component2 = () => {
	return (
		<div>
			<button onClick={() => iTwinUIToaster.positive("hello")}>show</button>;
		</div>
	);
};

// ------------------------------------------------------------------------------------------------
// usetheme-deprecated

// Should NOT be changed
const Component3 = () => {
	useTheme();

	return <Button>...</Button>;
};

// Should be changed
const Component4 = () => {
	iTwinUIUseTheme();

	return <Button>...</Button>;
};
