import { SvgSmileyHappy } from "@itwin/itwinui-icons-react";
import { RadioTile, RadioTileGroup } from "@itwin/itwinui-react";

// When wrapperProps already exists, we should do nothing.
// This is because looks like the user already know about wrapperProps.
// Thus, they likely wanted the className and/or style to really be applied to the <input> and not the wrapper.
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className="my-radio-tile"
    style={{ color: "red" }}
    wrapperProps={{
      onClick: () => {},
    }}
  />
</RadioTileGroup>;

// When wrapperProps does not already exist, we should add it along with className inside it.
// Both className and style
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className="my-radio-tile"
    style={{ color: "red" }}
  />
</RadioTileGroup>;

// Only className
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className="my-radio-tile"
  />
</RadioTileGroup>;

// Only style
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    style={{ color: "red" }}
  />
</RadioTileGroup>;

// className="string"
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className="my-radio-tile"
  />
</RadioTileGroup>;

// className={"string in expression"}
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className={"my-radio-tile"}
  />
</RadioTileGroup>;

// className={variable}
const myRadioTileClass = "my-radio-tile";
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className={myRadioTileClass}
  />
</RadioTileGroup>;

// className={variable + "string"}
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    className={myRadioTileClass + " my-radio-tile-2"}
  />
</RadioTileGroup>;

// style=object
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    style={{ color: "red" }}
  />
</RadioTileGroup>;

// style={variable}
const myRadioTileStyle = { color: "red" };
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    style={myRadioTileStyle}
  />
</RadioTileGroup>;

// style={complex expression}
const shouldApplyStyle = true;
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    style={
      shouldApplyStyle ? { backgroundColor: "green", ...myRadioTileStyle } : {}
    }
  />
</RadioTileGroup>;

// className and/or style as spread attribute (no action)
const props = {
  className: "my-radio-tile",
  style: { color: "red" },
};
<RadioTileGroup label="My group">
  <RadioTile
    label="My tile"
    description="Some info"
    icon={<SvgSmileyHappy />}
    {...props}
  />
</RadioTileGroup>;
