import { SvgSmileyHappy } from "@itwin/itwinui-icons-react";
import {
  Button,
  Checkbox,
  ColorPalette,
  ColorPicker,
  ComboBox,
  DatePicker,
  Dialog,
  Input,
  LabeledInput,
  LabeledTextarea,
  Menu,
  MenuItem,
  Radio,
  RadioTile,
  RadioTileGroup,
  Select,
  Slider,
  Textarea,
  TimePicker,
  ToggleSwitch,
} from "@itwin/itwinui-react";
import React from "react";

const MyComponent = () => {
  // setFocus should also be removed from the appropriate components in variables.
  const componentAsVariable = <Checkbox label="Checkbox label" setFocus />;

  // setFocus should also be removed from the appropriate components in sub components.
  const SubComponent = () => {
    return <Checkbox label="Checkbox label" setFocus />;
  };

  const setFocus = false;

  return (
    <div>
      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 1: If setFocus={false}, it can be auto-removed */}

      <Checkbox label="Checkbox label" setFocus={false} />
      <ColorPicker setFocus={false}>
        <ColorPalette colors={["#FFFFFF", "#5A6973"]} />
      </ColorPicker>
      <ComboBox
        options={[
          { label: "Item 1", value: 1 },
          { label: "Item 2", value: 2 },
          { label: "Item 3", value: 3 },
        ]}
        onChange={() => {}}
        inputProps={{
          setFocus: false,
          style: { backgroundColor: "red" },
        }}
      />
      <Input setFocus={false} />
      <LabeledInput label="My label" setFocus={false} />
      <LabeledTextarea
        label="Textarea Label"
        message="Help Message"
        placeholder="This is a textarea"
        setFocus={false}
      />
      <Radio label="Radio label" setFocus={false} />
      <RadioTileGroup>
        <RadioTile
          label="My tile"
          description="Some info"
          icon={<SvgSmileyHappy />}
          setFocus={false}
        />
      </RadioTileGroup>
      <Select options={[]} setFocus={false} />
      <Slider values={[50]} setFocus={false} />
      <Textarea placeholder="This is a textarea" setFocus={false} />
      <ToggleSwitch defaultChecked setFocus={false} />

      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 2.1: When setFocus={true}, automatically add autoFocus for simple cases (all except ColorPicker, Select, Slider) */}
      
      <Checkbox label="Checkbox label" setFocus={true} />
      <ComboBox
        options={[
          { label: "Item 1", value: 1 },
          { label: "Item 2", value: 2 },
          { label: "Item 3", value: 3 },
        ]}
        onChange={() => {}}
        inputProps={{
          setFocus: true,
        }}
      />
      <Input setFocus={true} />
      <LabeledInput label="My label" setFocus={true} />
      <LabeledTextarea
        label="Textarea Label"
        message="Help Message"
        placeholder="This is a textarea"
        setFocus={true}
      />
      <Radio label="Radio label" setFocus={true} />
      <RadioTileGroup>
        <RadioTile
          label="My tile"
          description="Some info"
          icon={<SvgSmileyHappy />}
          setFocus={true}
        />
      </RadioTileGroup>
      <Textarea placeholder="This is a textarea" setFocus={true} />
      <ToggleSwitch defaultChecked setFocus={true} />

      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 2.2: For Select, we automatically use triggerProps */}

      <Select options={[]} setFocus={true} />

      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 2.3: ColorPicker and Slider are outliers, so we do no automated changes. We just give manual suggestions */}

      <ColorPicker setFocus={true}>
        <ColorPalette colors={["#FFFFFF", "#5A6973"]} />
      </ColorPicker>      
      <Slider values={[50]} setFocus={true} />

      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 3: Some cases where setFocus cannot be auto-removed */}

      {/* setFocus={someVariable} (add manual suggestion) */}
      <Checkbox label="Checkbox label" setFocus={setFocus} />
      {/* setFocus is passed by using spread (no automated change or manual suggestion since we don't see inside spread) */}
      <Checkbox label="Checkbox label" {...{ setFocus }} />

      {/* ------------------------------------------------------------------------------------------------ */}
      {/* Test 4: Test for false positives */}

      {/* setFocus should not be removed from components that still have setFocus */}
      <DatePicker date={new Date()} setFocus />
      <Dialog isOpen={true} trapFocus preventDocumentScroll setFocus>
        <Dialog.Backdrop />
        <Dialog.Main aria-modal>
          <Dialog.TitleBar>My dialog title</Dialog.TitleBar>
          <Dialog.Content>Here is my dialog content</Dialog.Content>
          <Dialog.ButtonBar>
            <Button styleType="high-visibility">Confirm</Button>
            <Button>Close</Button>
          </Dialog.ButtonBar>
        </Dialog.Main>
      </Dialog>
      <Menu setFocus>
        <MenuItem>1</MenuItem>
        <MenuItem>2</MenuItem>
      </Menu>
      <TimePicker date={new Date()} setFocusHour />
    </div>
  );
};
