import {
  SvgFlag,
  SvgFolderOpened,
  SvgHome,
  SvgSettings,
} from "@itwin/itwinui-icons-react";
import { SideNavigation, SidenavButton } from "@itwin/itwinui-react";
import React from "react";

const items = [
  <SidenavButton startIcon={<SvgHome />} key={0}>
    Home
  </SidenavButton>,
  <SidenavButton startIcon={<SvgFlag />} key={1}>
    Issues
  </SidenavButton>,
  <SidenavButton startIcon={<SvgFolderOpened />} key={2} disabled>
    Documents
  </SidenavButton>,
];

const secondaryItems = [
  <SidenavButton startIcon={<SvgSettings />} key={3}>
    Settings
  </SidenavButton>,
];

// When wrapperProps already exists, we should do nothing.
// This is because looks like the user already know about wrapperProps.
// Thus, they likely wanted the className and/or style to really be applied to the inner div and not the wrapper.
<SideNavigation
  className="my-side-navigation"
  style={{ color: "red" }}
  wrapperProps={{
    onClick: () => {},
  }}
  items={items}
  secondaryItems={secondaryItems}
/>;

// When wrapperProps does not already exist, we should add it along with className inside it.
// Both className and style
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: "my-side-navigation",
    style: { color: "red" }
  }} />;

// Only className
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: "my-side-navigation"
  }}
/>;

// Only style
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    style: { color: "red" }
  }}
/>;

// className="string"
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: "my-side-navigation"
  }}
/>;

// className={"string in expression"}
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: "my-side-navigation"
  }}
/>;

// className={variable}
const mySideNavigationClass = "my-side-navigation";
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: mySideNavigationClass
  }}
/>;

// className={variable + "string"}
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    className: mySideNavigationClass + "my-side-navigation-2"
  }}
/>;

// style=object
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    style: { color: "red" }
  }}
/>;

// style={variable}
const mySideNavigationStyle = { color: "red" };
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    style: mySideNavigationStyle
  }}
/>;

// style={complex expression}
const shouldApplyStyle = true;
<SideNavigation
  items={items}
  secondaryItems={secondaryItems}
  wrapperProps={{
    style: shouldApplyStyle
      ? { backgroundColor: "green", ...mySideNavigationStyle }
      : {}
  }}
/>;

// className and/or style as spread attribute (no action)
const props = {
  className: "my-side-navigation",
  style: { color: "red" },
};
<SideNavigation items={items} secondaryItems={secondaryItems} {...props} />;