import { MenuItem, SplitButton } from "@itwin/itwinui-react";

const menuItems = () => [
  <MenuItem key={1}>Item #1</MenuItem>,
  <MenuItem key={2}>Item #2</MenuItem>,
];

// When wrapperProps already exists, we should do nothing.
// This is because looks like the user already know about wrapperProps.
// Thus, they likely wanted the className to really be applied to the button and not the wrapper.
<SplitButton
  className="my-button-class"
  aria-label={"More button"}
  menuItems={menuItems}
  wrapperProps={{
    onClick: () => {},
  }}
>
  ...
</SplitButton>;

// When wrapperProps does not already exist, we should add it along with className inside it.
// className="string"
<SplitButton
  className="my-button-class"
  aria-label={"More button"}
  menuItems={menuItems}
>
  ...
</SplitButton>;

// className={"string in expression"}
<SplitButton
  className={"my-button-class"}
  aria-label={"More button"}
  menuItems={menuItems}
>
  ...
</SplitButton>;

// className={variable}
const myButtonClass = "my-button-class";
<SplitButton
  className={myButtonClass}
  aria-label={"More button"}
  menuItems={menuItems}
>
  ...
</SplitButton>;

// className={variable + "string"}
<SplitButton
  className={myButtonClass + " my-button-class-2"}
  aria-label={"More button"}
  menuItems={menuItems}
>
  ...
</SplitButton>;

// className as spread attribute (no action)
const props = {
  className: "my-button-class",
};
<SplitButton {...props} aria-label={"More button"} menuItems={menuItems}>
  ...
</SplitButton>;
