import { useToaster } from "@itwin/itwinui-react";
import React from "react";

const MyComponent1 = () => {
  const toaster = useToaster();
  return (
    <div>
      <button onClick={() => toaster.positive("hello")}>show</button>;
    </div>
  );
};

// toaster inside return statement
const MyComponent2 = () => {
  const toaster = useToaster();
  return <button onClick={() => toaster.positive("hello")}>show</button>;
};

// toaster inside variable that stores an arrow function
const MyComponent3 = () => {
  const toaster = useToaster();
  const onClick = () => {
    toaster.positive("hello");
  };

  return <button onClick={onClick}>show</button>;
};

// toaster inside a deeply nested component.
// useToaster should be added to the outer most component only once
const MyComponent4 = () => {
  const toaster = useToaster();
  const MyComponent4_1 = () => {
    const MyComponent4_1_1 = () => {
      return <button onClick={() => toaster.positive("hello")}></button>;
    };

    return (
      <div>
        <MyComponent4_1_1 />
        <button onClick={() => toaster.positive("hello")}></button>
      </div>
    );
  };

  return <MyComponent4_1 />;
};

// When import alias is used, create a variable with the same name and assign useToaster to it
const MyComponent5 = () => {
  const iTwinUiToaster = useToaster();
  return <button onClick={() => iTwinUiToaster.positive("hello")}>show</button>;
};

// Should work for forward refs as well
const MyComponent6 = React.forwardRef(function MyComponent6(props, ref) {
  const toaster = useToaster();
  return (
    <button
      onClick={() => {
        toaster.informational("...");
      }}
    >
      Show
    </button>
  );
});

// eslint-disable-next-line react/display-name
const MyComponent7 = React.forwardRef((props, ref) => {
  const toaster = useToaster();
  return (
    <button
      onClick={() => {
        toaster.informational("...");
      }}
    >
      Show
    </button>
  );
});

// For class components, we do nothing. We just warn the user.
class MyComponent8 extends React.Component {
  render() {
    return <button onClick={() => toaster.positive("hello")}>show</button>;
  }
}