import * as React from "react";
import { ThemeProvider, useToaster } from "@itwin/itwinui-react";

// ------------------------------------------------------------------------------------------------
// useToaster() used outside of ThemeProvider in the same component
// Show manual suggestion

function Comp1() {
	useToaster(); // ❌
	return <ThemeProvider>...</ThemeProvider>;
}

// Deeper nesting of ThemeProvider should also trigger a suggestion
const SomeOtherProvider1 = ({ children }: { children: React.ReactNode }) => <div>{children}</div>;
const SomeOtherProvider2 = SomeOtherProvider1;

function Comp2() {
	useToaster(); // ❌
	return (
		<SomeOtherProvider1>
			<SomeOtherProvider2>
				<div>
					<ThemeProvider>...</ThemeProvider>
				</div>
			</SomeOtherProvider2>
		</SomeOtherProvider1>
	);
}

// Complex cases should also trigger a suggestion
function Comp3() {
	useToaster(); // ❌
	return (
		<div>
			{(() => {
				const MyThemeProvider = ({
					theme,
					children,
				}: { theme: "light"; children: React.ReactNode }) => (
					<ThemeProvider theme={theme}>{children}</ThemeProvider>
				);

				return <MyThemeProvider theme="light">...</MyThemeProvider>;
			})()}
		</div>
	);
}

// ------------------------------------------------------------------------------------------------
// Use of ThemeProvider and useToaster() in different components is not a supported trigger for a suggestion
// So no manual suggestions shown

function Comp4Wrapper() {
	return (
		<ThemeProvider>
			<Comp4 />
		</ThemeProvider>
	);
}
function Comp4() {
	useToaster(); // ✅

	return <div>...</div>;
}

// ------------------------------------------------------------------------------------------------
// Test for false positives:
// If no ThemeProvider is in the scope of the return, then the suggestion should not be triggered
// So no manual suggestions shown

function Comp5() {
	useToaster(); // ✅
	return <div>...</div>;
}
