import type { API, FileInfo, Options } from "jscodeshift";
import {
	getImportAliasToRealComponentMapping,
	getSafeCodemoddedSource,
	renameProp,
} from "../utils/codemods";

/**
 * Codemod for the below change:
 * > [#1295](https://github.com/iTwin/iTwinUI/pull/1295): Deprecated `icon` and `badge` props in favor of new `startIcon` and `endIcon` props. Also affects Select and ComboBox options.
 */
const menuItemIconBadgeDeprecated = (fileInfo: FileInfo, api: API, options: Options): string => {
	const j = api.jscodeshift;
	const root = j(fileInfo.source);

	let hasChanged = false;

	const menuItemMigrationGuideLink = `https://github.com/iTwin/iTwinUI/wiki/iTwinUI-react-v3-migration-guide#menuitem`;

	const importAliasToRealComponentMapping = getImportAliasToRealComponentMapping(j, root, [
		"MenuItem",
	]);
	Object.keys(importAliasToRealComponentMapping).forEach((menuItemAlias) => {
		const menuItems = root.findJSXElements(menuItemAlias);
		menuItems.forEach((menuItem) => {
			// Rename icon to startIcon and badge to endIcon
			const newHasChanged = renameProp({
				fileInfo,
				path: menuItem,
				oldPropName: "icon",
				newPropName: "startIcon",
				seeLink: menuItemMigrationGuideLink,
				codemod: "menuitem-icon-badge-deprecated",
			});
			const newHasChanged1 = renameProp({
				fileInfo,
				path: menuItem,
				oldPropName: "badge",
				newPropName: "endIcon",
				seeLink: menuItemMigrationGuideLink,
				codemod: "menuitem-icon-badge-deprecated",
			});

			hasChanged = hasChanged || newHasChanged || newHasChanged1;
		});
	});

	return getSafeCodemoddedSource({
		root,
		fileInfo,
		hasChanged,
	});
};

export default menuItemIconBadgeDeprecated;
