import type { API, FileInfo, Options } from "jscodeshift";
import {
	getSafeCodemoddedSource,
	moveClassNameAndStylePropsToWrapperProps,
} from "../utils/codemods";

/**
 * Codemod for the below change:
 * > [#1409](https://github.com/iTwin/iTwinUI/pull/1409): `RadioTile`'s `className` and `style` props will now always be applied on the `<input>` element instead of conditionally being applied on the wrapper when label is passed. Added `wrapperProps`, `iconProps`, `labelProps`, `subLabelProps` to individually customize each part of the component.
 * > ```diff
 * >   <Radio
 * >     label = 'Radio label'
 * > -   className={wrapperClassname}
 * > -   style={wrapperStyle}
 * > +   wrapperProps={{ className: wrapperClassName, style: wrapperStyle }}
 * >   />
 * > ```
 */
const radioTileMoveStyleClassInside = (fileInfo: FileInfo, api: API, options: Options): string => {
	const j = api.jscodeshift;
	const root = j(fileInfo.source);

	const hasChanged = moveClassNameAndStylePropsToWrapperProps({
		j,
		root,
		componentName: "RadioTile",
	});

	return getSafeCodemoddedSource({
		root,
		fileInfo,
		hasChanged,
	});
};

export default radioTileMoveStyleClassInside;
