import { API, FileInfo, ImportDeclaration, Options } from "jscodeshift";
import { getSafeCodemoddedSource } from "../utils/codemods";

/**
 * Codemod for the below change:
 * > [#1514](https://github.com/iTwin/iTwinUI/pull/1514): Removed dependency on `@types/react-table` and instead exposed a package endpoint `/react-table` for all `react-table` types. Our types are specifically tailored to the users of our Table and thus offer better type support.
 * >  ```diff
 * > import { Table } from '@itwin/itwinui-react';
 * > - import { Column, TableState } from 'react-table';
 * > + import { Column, TableState } from '@itwin/itwinui-react/react-table';
 * > ```
 * @param fileInfo
 * @param api
 * @param options
 */
const reactTableImport = (fileInfo: FileInfo, api: API, options: Options): string => {
	const j = api.jscodeshift;
	const root = j(fileInfo.source);

	let hasChanged = false;

	const importDeclarations = root.find(j.ImportDeclaration);
	importDeclarations.forEach((element) => {
		const importDeclaration = element.node as ImportDeclaration;
		if (importDeclaration.source.value == "react-table") {
			importDeclaration.source.value = "@itwin/itwinui-react/react-table";

			hasChanged = true;
		}
	});

	return getSafeCodemoddedSource({
		root,
		fileInfo,
		hasChanged,
	});
};

export default reactTableImport;
