import type { API, FileInfo, Options } from "jscodeshift";
import {
	getSafeCodemoddedSource,
	moveClassNameAndStylePropsToWrapperProps,
} from "../utils/codemods";

/**
 * Codemod for the below change:
 * > [#1458](https://github.com/iTwin/iTwinUI/pull/1458): Top-level props (className, style, etc) now passed to the main inner div instead of to the wrapper. Use `wrapperProps` to restore old behavior.
 */
const sideNavigationMoveStyleClassInside = (
	fileInfo: FileInfo,
	api: API,
	options: Options,
): string => {
	const j = api.jscodeshift;
	let root = j(fileInfo.source);

	const hasChanged = moveClassNameAndStylePropsToWrapperProps({
		j,
		root,
		componentName: "SideNavigation",
	});

	return getSafeCodemoddedSource({
		root,
		fileInfo,
		hasChanged,
	});
};

export default sideNavigationMoveStyleClassInside;
