import { SvgStatusError } from "@itwin/itwinui-icons-react";
import { MatchFile } from "data/file_types";
import {
	implementAllAutoswapChanges,
	setAllManualChanges,
	setAllSuggestionChanges,
} from "utils/tasks";
import { DialogContent } from "../InstructionsSection";

export const getAllAutoswapChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
	lockAllOperations: boolean,
	setLockAllOperations: any,
): DialogContent => {
	return {
		type: "autoswap",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="autoswap" />
				Implement all autoswaps?
			</span>
		),
		content: (
			<>
				{`"autoswap" changes are `}
				<strong>NOT PERFECT</strong>
				{`. Proceeding will attempt to write `}
				<strong>ALL</strong>
				{` "autoswap" change recommendations displayed here. `}
				<br />
				<br />
				{`It is recommended you still do a `}
				<strong>quick manual scan</strong>
				{` after running this to confirm if all changes match your needs.`}
			</>
		),
		proceedButtonClickHandler: () => {
			implementAllAutoswapChanges(
				true,
				matches,
				setMatches,
				lockAllOperations,
				setLockAllOperations,
			);
		},
	};
};

export const getUndoAllAutoswapChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
	lockAllOperations: boolean,
	setLockAllOperations: any,
): DialogContent => {
	return {
		type: "autoswap",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="autoswap" />
				Undo all autoswaps?
			</span>
		),
		content: <>{`This will attempt to undo all the changes written to the files.`}</>,
		proceedButtonClickHandler: () => {
			implementAllAutoswapChanges(
				false,
				matches,
				setMatches,
				lockAllOperations,
				setLockAllOperations,
			);
		},
	};
};

export const getAllManualChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
): DialogContent => {
	return {
		type: "manual",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="manual" />
				Mark all manual as done?
			</span>
		),
		content: (
			<>
				{`This will just mark all manual changes as `}
				<strong>completed</strong>
				{` in the app. However, you will have to manually make these changes in your code.`}
			</>
		),
		proceedButtonClickHandler: () => {
			setAllManualChanges(true, matches, setMatches);
		},
	};
};

export const getUndoAllManualChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
): DialogContent => {
	return {
		type: "manual",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="manual" />
				Undo all manual?
			</span>
		),
		content: (
			<>
				{`This will just mark all "manual" changes as `}
				<strong>not completed</strong>
				{` in the app. However, you will have to manually undo these changes in your code.`}
			</>
		),
		proceedButtonClickHandler: () => {
			setAllManualChanges(false, matches, setMatches);
		},
	};
};
export const getAllSuggestionChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
): DialogContent => {
	return {
		type: "suggestion",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="suggestion" />
				Mark all suggestions as done?
			</span>
		),
		content: (
			<>
				{`This will just mark all "suggestion" changes as `}
				<strong>completed</strong>
				{` in the app. However, if you choose to follow the suggestion, you will have to manually make these changes in your code.`}
			</>
		),
		proceedButtonClickHandler: () => {
			setAllSuggestionChanges(true, matches, setMatches);
		},
	};
};

export const getUndoAllSuggestionChangesDialogContent = (
	matches: MatchFile[],
	setMatches: any,
): DialogContent => {
	return {
		type: "suggestion",
		title: (
			<span className="dialog-titlebar">
				<SvgStatusError className="icon" data-error="suggestion" />
				Undo all suggestions?
			</span>
		),
		content: (
			<>
				{`This will just mark all "suggestion" changes as `}
				<strong>not completed</strong>
				{` in the app. However, you will have to manually undo these changes in your code.`}
			</>
		),
		proceedButtonClickHandler: () => {
			setAllSuggestionChanges(false, matches, setMatches);
		},
	};
};
