import { iTwinPackage, MatchFile } from "data/file_types";
import type { NextApiRequest, NextApiResponse } from "next";
import { getAllFilesAndFolders, getMatchFiles, implementLineMatchChanges } from "scanner/logic";

export default async function handler(req: NextApiRequest, res: NextApiResponse) {
	if (req.method !== "GET" && req.method !== "POST") {
		res.status(405).send("Method not allowed");
		return;
	}

	// POST
	if (req.method === "POST") {
		const response = await implementLineMatchChanges(req.body);
		res.send(response);
		return;
	}

	// GET
	let searchFolders: string[] | null = null;
	let searchingType: "one-file" | "repo-folder" = "repo-folder"; // Flag since this method can either search one file or search all files/folders in given path

	if (req.query.fileName != null && typeof req.query.fileName === "string") {
		searchFolders = [req.query.fileName];
		searchingType = "one-file";
	} else if (req.query.repoFolder != null && typeof req.query.repoFolder === "string") {
		searchFolders = await getAllFilesAndFolders({
			repoFolder: req.query.repoFolder,
		});
	} else {
		res.status(422).send("Incorrect input");
		return;
	}

	if (req.query.packagesToScan == null) {
		res.status(422).send("Incorrect input: Missing packagesToScan");
		return;
	}

	let matches: MatchFile[] | null = null;
	if (searchFolders != null) {
		matches = await getMatchFiles(searchFolders, req.query.packagesToScan as iTwinPackage[]);
		if (matches != null) {
			res.send(matches);
			return;
		}
	}

	// Error finding matches

	if (searchingType === "one-file") {
		res.status(500).send(`Error finding matches in file: ${req.query.fileName}`);
		return;
	}

	// searchingType === "repo-folder"
	res.status(500).send(`Error finding matches in folder: ${req.query.folderName}`);
}
