import type { NextApiRequest, NextApiResponse } from "next";
import { openFile } from "scanner/logic";

export default async function handler(req: NextApiRequest, res: NextApiResponse) {
	if (req.method !== "GET") {
		res.status(405).send("Method not allowed");
		return;
	}

	try {
		if (
			req.query.fileName != null &&
			typeof req.query.fileName === "string" &&
			req.query.lineNumber != null &&
			typeof req.query.lineNumber === "string" &&
			req.query.columnNumber != null &&
			typeof req.query.columnNumber === "string"
		) {
			const success = await openFile(
				req.query.fileName,
				Number(req.query.lineNumber),
				Number(req.query.columnNumber),
			);
			if (!success) {
				throw "";
			}
		} else {
			res.status(422).send("Incorrect input");
			return;
		}
	} catch {
		res
			.status(500)
			.send(
				`Error opening file: ${req.query.fileName}:${req.query.lineNumber}:${req.query.columnNumber}`,
			);
		return;
	}

	res.send(
		`Attempted to open file: ${req.query.fileName}:${req.query.lineNumber}:${req.query.columnNumber}`,
	);
}
