import { FileStructure, FileTree } from "components/FileTree/FileTree";
import { FilesSection } from "components/FilesSection/FilesSection";
import { AppHeader } from "app/(routes)/AppHeader";
import { useToaster } from "@itwin/itwinui-react";
import React from "react";
import { FolderInfo, iTwinPackage, MatchLine } from "data/file_types";
import Head from "next/head";
import { RulesContext, RepoFolderContext, MatchesContext } from "modules/contexts/contexts";
import { setGlobalToaster } from "modules/globals/toaster";
import "styles/pages/v2/App.scss";

export default function App() {
	const repoFolder = React.useRef("");
	const [foundRepoFolder, setFoundRepoFolder] = React.useState(false);
	const [folderInfo, setFolderInfo] = React.useState<FolderInfo | null>(null);
	const [matches, setMatches] = React.useState([]);
	const [lockAllOperations, setLockAllOperations] = React.useState(false);
	const [gettingMatches, setGettingMatches] = React.useState(false);
	const [fileTree, setFileTree] = React.useState<FileStructure>();
	const [selectedFilters, setSelectedFilters] = React.useState<(MatchLine["type"] | "completed")[]>(
		["autoswap", "manual", "suggestion"],
	);
	const [packagesToScan, setPackagesToScan] = React.useState<iTwinPackage[]>([
		"itwinui-variables",
		"itwinui-css",
		"itwinui-react",
	]);

	// Initialize toaster
	setGlobalToaster(useToaster());

	return (
		<RulesContext.Provider value={{ packagesToScan, setPackagesToScan }}>
			<RepoFolderContext.Provider
				value={{
					repoFolder,
					foundRepoFolder,
					setFoundRepoFolder,
					folderInfo,
					setFolderInfo,
				}}
			>
				<MatchesContext.Provider
					value={{
						matches,
						setMatches,
						gettingMatches,
						setGettingMatches,
						fileTree,
						setFileTree,
						selectedFilters,
						setSelectedFilters,
						lockAllOperations,
						setLockAllOperations,
					}}
				>
					<Head>
						<title>{`iTwinUI Migration Tool (v1 → v2)`}</title>
						<link rel="icon" href="/favicon.svg" />
					</Head>
					<div className="App">
						<AppHeader />
						<span className="content">
							<FileTree />
							<FilesSection />
						</span>
					</div>
				</MatchesContext.Provider>
			</RepoFolderContext.Provider>
		</RulesContext.Provider>
	);
}
