import path from "path";
import { displayToast } from "./tasks";

export type OSType = "windows" | "unix";

export const getOperatingSystemType = (window: Window): OSType => {
	let operatingSystem: OSType = "unix"; // Default is unix
	if (window.navigator.appVersion.indexOf("Win") !== -1) {
		operatingSystem = "windows";
	}
	if (
		window.navigator.appVersion.indexOf("Mac") !== -1 ||
		window.navigator.appVersion.indexOf("X11") !== -1 ||
		window.navigator.appVersion.indexOf("Linux") !== -1
	) {
		operatingSystem = "unix";
	}

	return operatingSystem;
};

export const getOSFilePathSeparator = () => {
	const osValue = process.platform;

	if (osValue == "win32") {
		return "\\";
	} else {
		return "/";
	}
};

export const getOsFilePath = (filePath: string) => {
	const replace = new RegExp("/|/+|\\|\\\\+", "g");
	const separator = getOSFilePathSeparator();

	return filePath.replaceAll(replace, separator);
};

/**
 * Returns the file name along with the path related to the repo folder
 * If repoFolder is not provided, the entire path will be returned
 */
export const getFileNameAndPath = (filePath: string, repoFolder: string = "") => {
	const parsedFilePath = path.parse(filePath.replaceAll("\\", "/"));
	const fileName = parsedFilePath.base;
	const dirName = parsedFilePath.dir;
	const filePathFromRepo = dirName.slice(repoFolder.length);

	return {
		fileName: fileName,
		path: filePathFromRepo,
	};
};

export const removeMultipleSlashes = (str: string, window: Window) => {
	const osType = getOperatingSystemType(window);
	let replace = /\/\/+/g;
	let replaceWith = "/";
	if (osType === "windows") {
		replace = /\\\\+/g;
		replaceWith = "\\";
	}

	return str.replaceAll(replace, replaceWith);
};
