import { SupportedCodemods } from "codemods/codemods";
import { runCodemodTransform } from "modules/v3/logic/codemods";
import fs from "node:fs";
import path from "node:path";
import { expect, test } from "vitest";

export const defineTest = (
	codemodToTest: SupportedCodemods,
	/**
	 * By default, it uses the files with just the codemodName and no suffix.
	 *
	 * To run tests that have a suffix, you can optionally pass `testNameSuffix`.
	 *
	 * @example
	 * // Uses usericon-deprecated.input.tsx and usericon-deprecated.output.tsx
	 * defineTest("usericon-deprecated");
	 *
	 * // Uses usericon-deprecated-1.input.tsx and usericon-deprecated-1.output.tsx
	 * defineTest("usericon-deprecated", "-1");
	 */
	testNameSuffix: string = "",
) => {
	const testsFolder = path.join(__dirname, `../codemods/__testfixtures__/${codemodToTest}`);
	const testName = `${codemodToTest}${testNameSuffix}`;

	const codeInputFile = path.join(testsFolder, `${testName}.input.tsx`);
	const expectedCodeOutputFile = path.join(testsFolder, `${testName}.output.tsx`);

	const codeInput = fs.readFileSync(codeInputFile, "utf-8");
	const expectedCode = fs.readFileSync(expectedCodeOutputFile, "utf-8");

	test(testName, () => {
		const actualCodeOutput = runCodemodTransform({
			codemod: codemodToTest,
			filePath: codeInputFile,
			codeInput: codeInput,
		});

		// If the codemod gives an error, fail the test
		if (actualCodeOutput == null) {
			expect(false);
		} else {
			expect(actualCodeOutput).toBe(expectedCode);
		}
	});
};
